==> ory_client-1.1.2.tar.gz: doc/ProjectBrandingTheme.md <==
# ory_client.model.ProjectBrandingTheme

## Load the model package
```dart
import 'package:ory_client/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**accentDefaultColor** | **String** | AccentDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentDisabledColor** | **String** | AccentDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentEmphasisColor** | **String** | AccentEmphasisColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentMutedColor** | **String** | AccentMutedColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentSubtleColor** | **String** | AccentSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**backgroundCanvasColor** | **String** | BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**backgroundSubtleColor** | **String** | BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**backgroundSurfaceColor** | **String** | BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**borderDefaultColor** | **String** | BorderDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**createdAt** | [**DateTime**](DateTime.md) | The Customiation Creation Date | 
**errorDefaultColor** | **String** | ErrorDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**errorEmphasisColor** | **String** | ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**errorMutedColor** | **String** | ErrorMutedColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**errorSubtleColor** | **String** | ErrorSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundDefaultColor** | **String** | ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundDisabledColor** | **String** | ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundMutedColor** | **String** | ForegroundMutedColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundOnAccentColor** | **String** | ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundOnDarkColor** | **String** | ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundOnDisabledColor** | **String** | ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundSubtleColor** | **String** | ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**id** | **String** | The customization theme ID. | 
**inputBackgroundColor** | **String** | InputBackgroundColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**inputDisabledColor** | **String** | InputDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**inputPlaceholderColor** | **String** | InputPlaceholderColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**inputTextColor** | **String** | InputTextColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**logoType** | **String** | Logo Type The Logo mime type. | [optional] 
**logoUrl** | **String** | Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket. | [optional] 
**name** | **String** | The customization theme name. | 
**primaryColor** | **String** | Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme. | [optional] 
**projectBrandingId** | **String** | The ProjectBranding ID this customization is associated with | 
**secondaryColor** | **String** | Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme. | [optional] 
**successEmphasisColor** | **String** | SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**textDefaultColor** | **String** | TextDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**textDisabledColor** | **String** | TextDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**updatedAt** | [**DateTime**](DateTime.md) | Last Time Branding was Updated | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> ory_client-1.1.45.tar.gz: doc/ProjectBrandingTheme.md <==
# ory_client.model.ProjectBrandingTheme

## Load the model package
```dart
import 'package:ory_client/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**accentDefaultColor** | **String** | AccentDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentDisabledColor** | **String** | AccentDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentEmphasisColor** | **String** | AccentEmphasisColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentMutedColor** | **String** | AccentMutedColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**accentSubtleColor** | **String** | AccentSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**backgroundCanvasColor** | **String** | BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**backgroundSubtleColor** | **String** | BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**backgroundSurfaceColor** | **String** | BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**borderDefaultColor** | **String** | BorderDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**createdAt** | [**DateTime**](DateTime.md) | The Customization Creation Date. | 
**errorDefaultColor** | **String** | ErrorDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**errorEmphasisColor** | **String** | ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**errorMutedColor** | **String** | ErrorMutedColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**errorSubtleColor** | **String** | ErrorSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundDefaultColor** | **String** | ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundDisabledColor** | **String** | ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundMutedColor** | **String** | ForegroundMutedColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundOnAccentColor** | **String** | ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundOnDarkColor** | **String** | ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundOnDisabledColor** | **String** | ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**foregroundSubtleColor** | **String** | ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**id** | **String** | The customization theme ID. | 
**inputBackgroundColor** | **String** | InputBackgroundColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**inputDisabledColor** | **String** | InputDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**inputPlaceholderColor** | **String** | InputPlaceholderColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**inputTextColor** | **String** | InputTextColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**logoType** | **String** | Logo Type The Logo mime type. | [optional] 
**logoUrl** | **String** | Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket. | [optional] 
**name** | **String** | The customization theme name. | 
**primaryColor** | **String** | Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme. | [optional] 
**projectBrandingId** | **String** | The ProjectBranding ID this customization is associated with. | 
**secondaryColor** | **String** | Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme. | [optional] 
**successEmphasisColor** | **String** | SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**textDefaultColor** | **String** | TextDefaultColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**textDisabledColor** | **String** | TextDisabledColor is a hex color code used by the Ory Account Experience theme. | [optional] 
**updatedAt** | [**DateTime**](DateTime.md) | Last Time Branding was Updated. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
